# Changelog

## [0.2.14a1](https://github.com/OpenVoiceOS/ovos-core/tree/0.2.14a1) (2024-11-19)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-core/compare/0.2.13...0.2.14a1)

**Merged pull requests:**

- requirements:skills list [\#599](https://github.com/OpenVoiceOS/ovos-core/pull/599) ([JarbasAl](https://github.com/JarbasAl))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
